Wciągniki, Wciągarki, Tensometry - Red Rooster Polska
Author: Red Rooster Industrial (UK) Ltd Sp. z o.o. Oddział w Polsce
Description: Specjaliści w Produkcji, Wynajmie i Serwisie Urządzeń Dźwigowych takich jak Wciągniki Łańcuchowe i Linowe, Wciągarki Pneumatyczne ( Elektryczne).
Keywords: Wciągarki łańcuchowe, wciągniki pneumatyczne, wagi przemysłowe, dynamometry, wciągarki elektryczne, wciągniki ręczne, wciągniki, wciągarki

Red Rooster Poland Sp. z o.o.
ul. Grabska 11, 32-005 Niepołomice, woj. małopolskie, Polska
tel: +48 12 27 85 666
e-mail: biuro@redrooster.com
50.032892, 20.191637
NIP: 6832085719, REGON:361257067
Sąd Rejonowy dla Krakowa- Śródmieścia,
XII Wydział Gospodarczy Krajowego Rejestru Sądowego
KRS 0000552395
Wysokość kapitału zakładowego: 2 305 000,00 PLN

- WCIĄGARKI
  PNEUMATYCZNE
  AIR HOISTS

  WCIĄGARKI
  PNEUMATYCZNE
  AIR HOISTS

- WCIĄGNIKI
  ŁAŃCUCHOWE
  NAWIJARKI LIN

  WCIĄGNIKI
  ŁAŃCUCHOWE
  NAWIJARKI LIN

- CIŚNIENIE
  PRACY
  4-6 barów

  CIŚNIENIE
  PRACY
  4-6 barów

- WAGI
  TENSOMETRYCZNE
  LOAD CELLS

  WAGI
  TENSOMETRYCZNE
  LOAD CELLS

- 25 LAT DOŚWIADCZENIA
  W BRANŻY
  URZĄDZEŃ DŹWIGOWYCH

  25 LAT DOŚWIADCZENIA
  W BRANŻY
  URZĄDZEŃ DŹWIGOWYCH

- GRONO ZADOWOLONYCH
  KLIENTÓW
  Z CAŁEGO ŚWIATA

  GRONO ZADOWOLONYCH
  KLIENTÓW
  Z CAŁEGO ŚWIATA

- NIEZAWODNE URZĄDZENIA
  SZEROKI ASORTYMENT
  CERTYFIKACJA ATEX

  NIEZAWODNE URZĄDZENIA
  SZEROKI ASORTYMENT
  CERTYFIKACJA ATEX

## BRANŻE

zobacz wszystkie branże

- ## BUDOWNICTWO
  PRZEMYSŁOWE

  ## PRZEMYSŁ

  ## MOTORYZACJA

  ## TRANSPORT

  ## GÓRNICTWO I WYDOBYCIE

Zatrudnimy na stanowisko: Specjalista ds.
Marketingu i PR
Filmy

## aktualności

zobacz wszystkie aktualności

- 19.10.2015

  Nowość w ofercie Red Rooster Poland Sp. z o.o.

  Od paździenika 2015 roku nasza oferta została wzbogacona o wciągniki pneumatyczne działające w zakresie ciśnienia pracy 4-6 bar.
  Urządzenia te charakteryzują się dużą prędkością podnoszenia, nowym systemem sterowania oraz jeszcze lepszym wyciszeniem.

  czytaj więcej

  12.05.2015

  Przygotowania do targów ITM Polska w Poznaniu - 9-12.06.2015

  Red Rooster bierze udział w corocznych targach HAPE. Nasze stoisko będzie można znaleźć w Salonie Hydrauliki, Pneumatyki i Napędów pod numerem 129.

  czytaj więcej

  04.04.2015

  Nowy kanał Red Rooster na www.youtube.com

  Serdecznie zapraszamy wszystkich odwiedzających naszą stronę internetową do odwiedzin nowo otwartego kanału Red Rooster Poland na YOUTUBE.
  Na naszym kanale umieszczamy filmy z prezentacją oferowanych przez nas urządzeń (wciągniki pneumatyczne).
  Żeby odwiedzić nas na YOUTUBE proszę kliknąć w ten link.

  czytaj więcej

- 23.07.2014

  Nowa strona www Red Rooster Poland Sp. z o.o.

  Mamy przyjemność zaprezentować Państwu nowa stronę www firmy Red Rooster. Aby ułatwić Państwa kontakt z pracownikami firmy strona została wyposażona w szereg informacji ułatwiających komunikację oraz formularze kontaktowe pozwalające złożyć klientowi w każdym momencie zapytanie dotyczące produktu czy usługi. Na stronie znajdą Państwo wszelkie informacje na temat oferowanego przez nas asortymentu, specyfikacje techniczne urządzeń w kategoriach: wciągniki, nawijarki lin, wciągarki, urządzenia pomiarowe, wózki oraz będą Państwo mogli pobrać katalogi i karty produktowe. Zapraszamy do odwiedzin i zapoznania się z firmą.
  www.redrooster.pl

  czytaj więcej

  07.07.2014

  Rozwój firmy w Polsce (wciągniki, wciągarki, wagi tensometryczne)

  II kwartał 2014 roku stał pod znakiem zwiększenia zatrudnienia w Red Rooster. Ogrom pracy oraz zwiększone zapotrzebowanie na urządzenia dźwigowe zdecydowanie wpłynęły na tempo rozwoju firmy w Polsce. Skład pracowników Red Rooster wzbogacił się o pracownika działu marketingu i sprzedaży, konstruktora oraz dwójkę pracowników produkcyjnych. Nowym pracownikom życzymy wielu sukcesów.
  Dodatkowo do hali produkcyjnej zostały zakupione nowe urządzenia do obróbki skrawaniem CNC oraz zostało utworzone i wyposażone stanowisko spawacza.

  czytaj więcej

  06.07.2014

  Jesteśmy w internecie

  Red Rooster Industrial UK Ltd Sp. z o.o. oddział w Polsce już na Facebooku, LinkedIn, Twitterze oraz Google+.
  Z dnia na dzień nasze profile przyciągają coraz większa liczbę osób zainteresowych tematyką urządzeń dźwigowych,
  wciągarek, wag przemysłowych i wciągników, nawijarek lin czy obróbki srawaniem.
  Zapraszamy do odwiedzin korzystając
  z odnośników umieszczonych na dole naszej strony www.

  czytaj więcej

# nowości produktowe
(wciągarki, wciągniki, wagi przemysłowe, wózki)

NOWOŚĆ
WCIĄGNIK PNEUMATYCZNY TMH-3000
WCIĄGNIKI ŁAŃCUCHOWE PNEUMATYCZNE TYPU BIG BAG
Miernik obciążenia RRI-T
(TENSOMETR)
WCIĄGNIK ŁAŃCUCHOWY PNEUMATYCZNY ULTRA NISKIEGO PRZEŚWITU TCR-6000-ULHR
Czujnik naciskowy
(dynamometr) SWLC750
Szekla z miernikiem
obciążenia
SWLS SWLST
Waga dźwigowa TEO
(waga przemysłowa)
Wciągnik pneumatyczny
TCR - 1000/2-AT2S
WCIĄGNIK ŁAŃCUCHOWY Z WÓZKIEM TNC-50TW/4-AT50-2S
Wciągarki i wciągniki łańcuchowe z certyfikatem ATEX